from distutils.core import setup

setup(
    name='MeiFirstUpload',
    version='1.0',
    description='这是第一个对外发布的模块，此处是描述。 测试哦',
    author='mlwtc',
    author_email='meistudent@163.com',
    py_modules=['Duiwaifabumokuai.demo1','Duiwaifabumokuai.demo2'] #需要发布的模块
)